California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 053 - REVENUE BONDS. STATEWIDE VOTER APPROVAL. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1376040 | YES ON 53 - STOP BLANK CHECKS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
761010 | CA BUSINESS PAC, SP0NSORED BY CA CHAMBER OF COMMERCE (AKA CALBUSPAC) | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1378875 | NO ON PROP 53 - CALIFORNIANS TO PROTECT LOCAL CONTROL, A COALITION OF PUBLIC SAFETY, LOCAL GOVERNMENT, BUSINESS AND LABOR ORGANIZATIONS, GOVERNOR BROWN AND TAXPAYERS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1389930 | NO ON 53, NEIGHBORS DEFENDING LOCAL CONTROL | OPPOSE